package com.ruoyi.rc.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.rc.mapper.TDeptInfoMapper;
import com.ruoyi.rc.domain.TDeptInfo;
import com.ruoyi.rc.service.ITDeptInfoService;

/**
 * 装置信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@Service
public class TDeptInfoServiceImpl implements ITDeptInfoService 
{
    @Autowired
    private TDeptInfoMapper tDeptInfoMapper;

    /**
     * 查询装置信息
     * 
     * @param id 装置信息主键
     * @return 装置信息
     */
    @Override
    public TDeptInfo selectTDeptInfoById(Long id)
    {
        return tDeptInfoMapper.selectTDeptInfoById(id);
    }

    /**
     * 查询装置信息列表
     * 
     * @param tDeptInfo 装置信息
     * @return 装置信息
     */
    @Override
    public List<TDeptInfo> selectTDeptInfoList(TDeptInfo tDeptInfo)
    {
        return tDeptInfoMapper.selectTDeptInfoList(tDeptInfo);
    }

    /**
     * 新增装置信息
     * 
     * @param tDeptInfo 装置信息
     * @return 结果
     */
    @Override
    public int insertTDeptInfo(TDeptInfo tDeptInfo)
    {
        return tDeptInfoMapper.insertTDeptInfo(tDeptInfo);
    }

    /**
     * 修改装置信息
     * 
     * @param tDeptInfo 装置信息
     * @return 结果
     */
    @Override
    public int updateTDeptInfo(TDeptInfo tDeptInfo)
    {
        return tDeptInfoMapper.updateTDeptInfo(tDeptInfo);
    }

    /**
     * 批量删除装置信息
     * 
     * @param ids 需要删除的装置信息主键
     * @return 结果
     */
    @Override
    public int deleteTDeptInfoByIds(Long[] ids)
    {
        return tDeptInfoMapper.deleteTDeptInfoByIds(ids);
    }

    /**
     * 删除装置信息信息
     * 
     * @param id 装置信息主键
     * @return 结果
     */
    @Override
    public int deleteTDeptInfoById(Long id)
    {
        return tDeptInfoMapper.deleteTDeptInfoById(id);
    }
}
